@@ -10,11 +10,14 @@
 #include "breeze.h"
 #include "breezemetrics.h"
 #include "breezeanimationdata.h"
+#include "breezesettings.h"
 #include "config-breeze.h"
 
 #include <KColorScheme>
 #include <KSharedConfig>
+#include <KConfigWatcher>
 
+#include <QToolBar>
 #include <QPainterPath>
 #include <QIcon>
 #include <QWidget>
@@ -24,12 +27,22 @@ namespace Breeze
 
     //* breeze style helper class.
     /** contains utility functions used at multiple places in both breeze style and breeze window decoration */
-    class Helper
+    class Helper : public QObject
     {
+        Q_OBJECT
+
         public:
 
+        enum class FrameHint {
+            None       = 0,
+            DoubleRing = 1,
+        };
+
+        Q_ENUM(FrameHint)
+        Q_DECLARE_FLAGS(FrameHints, FrameHint)
+
         //* constructor
-        explicit Helper( KSharedConfig::Ptr );
+        explicit Helper( KSharedConfig::Ptr, QObject *parent = nullptr );
 
         //* destructor
         virtual ~Helper()
@@ -41,6 +54,9 @@ namespace Breeze
         //* pointer to shared config
         KSharedConfig::Ptr config() const;
 
+        //* pointer to kdecoration config
+        QSharedPointer<InternalSettings> decorationConfig() const;
+
         //*@name color utilities
         //@{
 
@@ -81,7 +97,7 @@ namespace Breeze
 
         //* titlebar text color
         const QColor& titleBarTextColor( bool active ) const
-        { return active ? _activeTitleBarTextColor:_inactiveTitleBarTextColor; }
+        { return active ? _activeTitleBarTextColor : _inactiveTitleBarTextColor; }
 
         //* frame outline color, using animations
         QColor frameOutlineColor( const QPalette&, bool mouseOver = false, bool hasFocus = false, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
@@ -157,7 +173,7 @@ namespace Breeze
         void renderFocusLine( QPainter*, const QRect&, const QColor& ) const;
 
         //* generic frame
-        void renderFrame( QPainter*, const QRect&, const QColor& color, const QColor& outline = QColor() ) const;
+        void renderFrame( QPainter*, const QRect&, const QColor& color, const QColor& outline = QColor(), FrameHints hints = FrameHint::None ) const;
 
         //* side panel frame
         void renderSidePanelFrame( QPainter*, const QRect&, const QColor& outline, Side ) const;
@@ -263,6 +279,9 @@ namespace Breeze
         //* returns true if a given widget supports alpha channel
         bool hasAlphaChannel( const QWidget* ) const;
 
+        //* returns true if the tools area should be drawn
+        bool shouldDrawToolsArea ( const QWidget* ) const;
+
         //@}
 
         //* return device pixel ratio for a given pixmap
@@ -295,6 +314,12 @@ namespace Breeze
         //* configuration
         KSharedConfig::Ptr _config;
 
+        //* KWin configuration
+        KSharedConfig::Ptr _kwinConfig;
+
+        //* decoration configuration
+        QSharedPointer<InternalSettings> _decorationConfig;
+
         //*@name brushes
         //@{
         KStatefulBrush _viewFocusBrush;
@@ -313,6 +338,10 @@ namespace Breeze
         QColor _inactiveTitleBarTextColor;
         //@}
 
+        mutable bool _cachedAutoValid = false;
+
+        friend class ToolsAreaManager;
+
     };
 
 }
