@@ -43,8 +43,8 @@
 
 #if BREEZE_HAVE_QTQUICK
 // needed to enable dragging from QQuickWindows
-#include <QQuickItem>
 #include <QQuickWindow>
+#include <QQuickRenderControl>
 #endif
 
 namespace Util
@@ -184,7 +184,8 @@ namespace Breeze
     {
         if ( !item ) return;
 
-        if( auto window = item->window() )
+        auto window = item->window();
+        if( window && window->objectName() != QStringLiteral("QQuickOffScreenWindow"))
         {
             auto contentItem = window->contentItem();
             contentItem->setAcceptedMouseButtons( Qt::LeftButton );
@@ -280,10 +281,12 @@ namespace Breeze
         {
 
             _dragTimer.stop();
+            setLocked( false );
             if( _target ) startDrag( _target.data()->window()->windowHandle() );
             #if BREEZE_HAVE_QTQUICK
             else if( _quickTarget ) startDrag( _quickTarget.data()->window() );
             #endif
+            resetDrag();
 
         } else {
 
